The application collects information concerning users' sex life, but the privacy policy does not disclose this. This type of data is a special category of personal information under regulations like GDPR and is extremely sensitive. Failure to inform users about this collection is a very serious issue and likely violates legal requirements for explicit consent and the most stringent data protection measures.